@@ -68,7 +68,8 @@ sub run {
     }
 
     foreach my $file ($info->sorted_index) {
-        my $fileinfo = $info->file_info($file);
+        next if not $file->is_file;
+        my $fileinfo = $file->file_info;
         if ($fileinfo =~ m/^[^,]*\bELF\b/ && $fileinfo =~ m/shared object/) {
             $sharedobject{$file} = 1;
         }
@@ -599,7 +600,9 @@ sub run {
         my %seen;
         @symbols_depends = grep { !$seen{$_}++ } @symbols_depends;
         for my $depend (@symbols_depends) {
-            unless ($provides->implies($depend)) {
+            my $d = $depend;
+            $d =~ s/ \#MINVER\#$//;
+            unless ($provides->implies($d)) {
                 tag 'symbols-declares-dependency-on-other-package', $depend;
             }
         }
